@@ -105,7 +105,7 @@ def model_update(
     if nomitall == "nomitall-prod":
         nomitall_url = "https://user.api.nomnomdata.com/api/1/"
     elif nomitall == "nomitall-stage":
-        nomitall_url = "https://staging.user.api.nomnomdata.com/api/1/"
+        nomitall_url = "https://user.api.staging.nomnomdata.com/api/1/"
     else:
         nomitall_url = nomitall
     if not org:
@@ -114,9 +114,7 @@ def model_update(
         config = get_nomitall_config(nomitall_url)
         org = profile.get(config["COGNITO_USERPOOL_ID"], {}).get("default-org")
         if not org:
-            raise ClickException(
-                f"No profile found for nomitall {nomitall_url}, try re-logging with `nnd login --nomitall-url {nomitall_url}`"
-            )
+            raise ClickException(f"User not authenticated.  Please run 'nnd login'")
     if channel == "beta":
         c_color = click.style(channel, fg="yellow", bold=True)
     elif channel == "stable":
